==> at-spi-0.0.4.tar.gz: at-spi-0.0.4/libspi/libspi.h <==
/* ATK -  Accessibility Toolkit
 * Copyright 2001 Ximian, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * libspi.h: the main include header for libspi.
 */
#ifndef LIBSPI_H_
#define LIBSPI_H_

#include <libspi/Accessibility.h>
#include <libspi/accessible.h>
#include <libspi/action.h>
#include <libspi/application.h>
#include <libspi/component.h>
#include <libspi/desktop.h>
#include <libspi/editabletext.h>
#include <libspi/hyperlink.h>
#include <libspi/hypertext.h>
#include <libspi/image.h>
#include <libspi/relation.h>
#include <libspi/selection.h>
#include <libspi/table.h>
#include <libspi/text.h>
#include <libspi/value.h>
#include <libspi/listener.h>
#include <libspi/keystrokelistener.h>
#include <libspi/accessibleeventlistener.h>
#include <libspi/deviceeventcontroller.h>
#include <libspi/registry.h>
#include <libspi/keymasks.h>

#endif /* LIBSPI_H_ */

==> at-spi-1.0.1.tar.gz: at-spi-1.0.1/libspi/libspi.h <==
/*
 * AT-SPI - Assistive Technology Service Provider Interface
 * (Gnome Accessibility Project; http://developer.gnome.org/projects/gap)
 *
 * Copyright 2001 Ximian, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * libspi.h: the main include header for libspi.
 */
#ifndef LIBSPI_H_
#define LIBSPI_H_

#include <libspi/Accessibility.h>
#include <libspi/accessible.h>
#include <libspi/action.h>
#include <libspi/application.h>
#include <libspi/component.h>
#include <libspi/editabletext.h>
#include <libspi/hyperlink.h>
#include <libspi/hypertext.h>
#include <libspi/image.h>
#include <libspi/relation.h>
#include <libspi/selection.h>
#include <libspi/stateset.h>
#include <libspi/table.h>
#include <libspi/text.h>
#include <libspi/value.h>
#include <libspi/listener.h>
#include <libspi/eventlistener.h>
#include <libspi/keystrokelistener.h>
#include <libspi/keymasks.h>
#include <libspi/remoteobject.h>

#endif /* LIBSPI_H_ */
